← Back to team overview

openlp-core team mailing list archive

[Merge] lp:~googol/openlp/bug-816382 into lp:openlp

 

Andreas Preikschat has proposed merging lp:~googol/openlp/bug-816382 into lp:openlp.

Requested reviews:
  OpenLP Core (openlp-core)
Related bugs:
  Bug #816382 in OpenLP: "Formatting Tags or Display Tags?"
  https://bugs.launchpad.net/openlp/+bug/816382

For more details, see:
https://code.launchpad.net/~googol/openlp/bug-816382/+merge/69879

Hello,

String fixes, bug #16382 (Formatting Tags or Display Tags?)

I also moved/renamed the py files and change the code accordingly. Where not possible I added comments (e. g. saving/loading formatting tags).
-- 
https://code.launchpad.net/~googol/openlp/bug-816382/+merge/69879
Your team OpenLP Core is requested to review the proposed merge of lp:~googol/openlp/bug-816382 into lp:openlp.
=== modified file 'openlp/core/lib/__init__.py'
--- openlp/core/lib/__init__.py	2011-07-16 09:00:30 +0000
+++ openlp/core/lib/__init__.py	2011-07-30 08:21:12 +0000
@@ -205,7 +205,7 @@
     text = text.replace(u'<br>', u'\n')
     text = text.replace(u'{br}', u'\n')
     text = text.replace(u'&nbsp;', u' ')
-    for tag in DisplayTags.get_html_tags():
+    for tag in FormattingTags.get_html_tags():
         text = text.replace(tag[u'start tag'], u'')
         text = text.replace(tag[u'end tag'], u'')
     return text
@@ -214,7 +214,7 @@
     """
     Expand tags HTML for display
     """
-    for tag in DisplayTags.get_html_tags():
+    for tag in FormattingTags.get_html_tags():
         text = text.replace(tag[u'start tag'], tag[u'start html'])
         text = text.replace(tag[u'end tag'], tag[u'end html'])
     return text
@@ -234,7 +234,7 @@
         pass
 
 from listwidgetwithdnd import ListWidgetWithDnD
-from displaytags import DisplayTags
+from formattingtags import FormattingTags
 from eventreceiver import Receiver
 from spelltextedit import SpellTextEdit
 from settingsmanager import SettingsManager

=== renamed file 'openlp/core/lib/displaytags.py' => 'openlp/core/lib/formattingtags.py'
--- openlp/core/lib/displaytags.py	2011-07-16 09:00:30 +0000
+++ openlp/core/lib/formattingtags.py	2011-07-30 08:21:12 +0000
@@ -25,12 +25,12 @@
 # Temple Place, Suite 330, Boston, MA 02111-1307 USA                          #
 ###############################################################################
 """
-Provide Html Tag management and Display Tag access class
+Provide HTML Tag management and Formatting Tag access class
 """
 
 from openlp.core.lib import translate
 
-class DisplayTags(object):
+class FormattingTags(object):
     """
     Static Class to HTML Tags to be access around the code the list is managed
     by the Options Tab.
@@ -42,89 +42,93 @@
         """
         Provide access to the html_expands list.
         """
-        return DisplayTags.html_expands
+        return FormattingTags.html_expands
 
     @staticmethod
     def reset_html_tags():
         """
         Resets the html_expands list.
         """
-        DisplayTags.html_expands = []
+        FormattingTags.html_expands = []
         base_tags = []
         # Append the base tags.
         # Hex Color tags from http://www.w3schools.com/html/html_colornames.asp
-        base_tags.append({u'desc': translate('OpenLP.DisplayTags', 'Red'),
+        base_tags.append({u'desc': translate('OpenLP.FormattingTags', 'Red'),
             u'start tag': u'{r}',
             u'start html': u'<span style="-webkit-text-fill-color:red">',
             u'end tag': u'{/r}', u'end html': u'</span>', u'protected': True})
-        base_tags.append({u'desc':  translate('OpenLP.DisplayTags', 'Black'),
+        base_tags.append({u'desc':  translate('OpenLP.FormattingTags', 'Black'),
             u'start tag': u'{b}',
             u'start html': u'<span style="-webkit-text-fill-color:black">',
             u'end tag': u'{/b}', u'end html': u'</span>', u'protected': True})
-        base_tags.append({u'desc': translate('OpenLP.DisplayTags', 'Blue'),
+        base_tags.append({u'desc': translate('OpenLP.FormattingTags', 'Blue'),
             u'start tag': u'{bl}',
             u'start html': u'<span style="-webkit-text-fill-color:blue">',
             u'end tag': u'{/bl}', u'end html': u'</span>', u'protected': True})
-        base_tags.append({u'desc': translate('OpenLP.DisplayTags', 'Yellow'),
+        base_tags.append({u'desc': translate('OpenLP.FormattingTags', 'Yellow'),
             u'start tag': u'{y}',
             u'start html': u'<span style="-webkit-text-fill-color:yellow">',
             u'end tag': u'{/y}', u'end html': u'</span>', u'protected': True})
-        base_tags.append({u'desc': translate('OpenLP.DisplayTags', 'Green'),
+        base_tags.append({u'desc': translate('OpenLP.FormattingTags', 'Green'),
             u'start tag': u'{g}',
             u'start html': u'<span style="-webkit-text-fill-color:green">',
             u'end tag': u'{/g}', u'end html': u'</span>', u'protected': True})
-        base_tags.append({u'desc': translate('OpenLP.DisplayTags', 'Pink'),
+        base_tags.append({u'desc': translate('OpenLP.FormattingTags', 'Pink'),
             u'start tag': u'{pk}',
             u'start html': u'<span style="-webkit-text-fill-color:#FFC0CB">',
             u'end tag': u'{/pk}', u'end html': u'</span>', u'protected': True})
-        base_tags.append({u'desc': translate('OpenLP.DisplayTags', 'Orange'),
+        base_tags.append({u'desc': translate('OpenLP.FormattingTags', 'Orange'),
             u'start tag': u'{o}',
             u'start html': u'<span style="-webkit-text-fill-color:#FFA500">',
             u'end tag': u'{/o}', u'end html': u'</span>', u'protected': True})
-        base_tags.append({u'desc': translate('OpenLP.DisplayTags', 'Purple'),
+        base_tags.append({u'desc': translate('OpenLP.FormattingTags', 'Purple'),
             u'start tag': u'{pp}',
             u'start html': u'<span style="-webkit-text-fill-color:#800080">',
             u'end tag': u'{/pp}', u'end html': u'</span>', u'protected': True})
-        base_tags.append({u'desc': translate('OpenLP.DisplayTags', 'White'),
+        base_tags.append({u'desc': translate('OpenLP.FormattingTags', 'White'),
             u'start tag': u'{w}',
             u'start html': u'<span style="-webkit-text-fill-color:white">',
             u'end tag': u'{/w}', u'end html': u'</span>', u'protected': True})
         base_tags.append({
-            u'desc': translate('OpenLP.DisplayTags', 'Superscript'),
+            u'desc': translate('OpenLP.FormattingTags', 'Superscript'),
             u'start tag': u'{su}', u'start html': u'<sup>',
             u'end tag': u'{/su}', u'end html': u'</sup>', u'protected': True})
-        base_tags.append({u'desc': translate('OpenLP.DisplayTags', 'Subscript'),
+        base_tags.append({
+            u'desc': translate('OpenLP.FormattingTags', 'Subscript'),
             u'start tag': u'{sb}', u'start html': u'<sub>',
             u'end tag': u'{/sb}', u'end html': u'</sub>', u'protected': True})
-        base_tags.append({u'desc': translate('OpenLP.DisplayTags', 'Paragraph'),
+        base_tags.append({
+            u'desc': translate('OpenLP.FormattingTags', 'Paragraph'),
             u'start tag': u'{p}', u'start html': u'<p>', u'end tag': u'{/p}',
             u'end html': u'</p>', u'protected': True})
-        base_tags.append({u'desc': translate('OpenLP.DisplayTags', 'Bold'),
+        base_tags.append({u'desc': translate('OpenLP.FormattingTags', 'Bold'),
             u'start tag': u'{st}', u'start html': u'<strong>',
             u'end tag': u'{/st}', u'end html': u'</strong>',
             u'protected': True})
-        base_tags.append({u'desc': translate('OpenLP.DisplayTags', 'Italics'),
+        base_tags.append({
+            u'desc': translate('OpenLP.FormattingTags', 'Italics'),
             u'start tag': u'{it}', u'start html': u'<em>', u'end tag': u'{/it}',
             u'end html': u'</em>', u'protected': True})
-        base_tags.append({u'desc': translate('OpenLP.DisplayTags', 'Underline'),
+        base_tags.append({
+            u'desc': translate('OpenLP.FormattingTags', 'Underline'),
             u'start tag': u'{u}',
             u'start html': u'<span style="text-decoration: underline;">',
             u'end tag': u'{/u}', u'end html': u'</span>', u'protected': True})
-        base_tags.append({u'desc': translate('OpenLP.DisplayTags', 'Break'),
+        base_tags.append({u'desc': translate('OpenLP.FormattingTags', 'Break'),
             u'start tag': u'{br}', u'start html': u'<br>', u'end tag': u'',
             u'end html': u'', u'protected': True})
-        DisplayTags.add_html_tags(base_tags)
+        FormattingTags.add_html_tags(base_tags)
 
     @staticmethod
     def add_html_tags(tags):
         """
         Add a list of tags to the list
         """
-        DisplayTags.html_expands.extend(tags)
+        FormattingTags.html_expands.extend(tags)
 
     @staticmethod
     def remove_html_tag(tag_id):
         """
         Removes an individual html_expands tag.
         """
-        DisplayTags.html_expands.pop(tag_id)
+        FormattingTags.html_expands.pop(tag_id)

=== modified file 'openlp/core/lib/renderer.py'
--- openlp/core/lib/renderer.py	2011-07-17 13:15:13 +0000
+++ openlp/core/lib/renderer.py	2011-07-30 08:21:12 +0000
@@ -422,7 +422,7 @@
             to the list of slides. (unicode string)
 
         ``previous_raw``
-            The raw text (with display tags) which is know to fit on a slide,
+            The raw text (with formatting tags) which is know to fit on a slide,
             but is not yet added to the list of slides. (unicode string)
 
         ``html_list``
@@ -431,7 +431,7 @@
 
         ``raw_list``
             The elements which do not fit on a slide and needs to be processed
-            using the binary chop. The elements can contain display tags.
+            using the binary chop. The elements can contain formatting tags.
 
         ``separator``
             The separator for the elements. For lines this is ``u'<br>'`` and

=== modified file 'openlp/core/lib/spelltextedit.py'
--- openlp/core/lib/spelltextedit.py	2011-07-07 18:03:12 +0000
+++ openlp/core/lib/spelltextedit.py	2011-07-30 08:21:12 +0000
@@ -39,7 +39,7 @@
 
 from PyQt4 import QtCore, QtGui
 
-from openlp.core.lib import translate, DisplayTags
+from openlp.core.lib import translate, FormattingTags
 from openlp.core.lib.ui import checkable_action
 
 log = logging.getLogger(__name__)
@@ -114,7 +114,7 @@
                     popupMenu.insertMenu(popupMenu.actions()[0], spell_menu)
         tagMenu = QtGui.QMenu(translate('OpenLP.SpellTextEdit',
             'Formatting Tags'))
-        for html in DisplayTags.get_html_tags():
+        for html in FormattingTags.get_html_tags():
             action = SpellAction(html[u'desc'], tagMenu)
             action.correct.connect(self.htmlTag)
             tagMenu.addAction(action)
@@ -148,7 +148,7 @@
         """
         Replaces the selected text with word.
         """
-        for html in DisplayTags.get_html_tags():
+        for html in FormattingTags.get_html_tags():
             if tag == html[u'desc']:
                 cursor = self.textCursor()
                 if self.textCursor().hasSelection():

=== modified file 'openlp/core/ui/__init__.py'
--- openlp/core/ui/__init__.py	2011-06-12 16:02:52 +0000
+++ openlp/core/ui/__init__.py	2011-07-30 08:21:12 +0000
@@ -69,7 +69,7 @@
 from aboutform import AboutForm
 from pluginform import PluginForm
 from settingsform import SettingsForm
-from displaytagform import DisplayTagForm
+from formattingtagform import FormattingTagForm
 from shortcutlistform import ShortcutListForm
 from mediadockmanager import MediaDockManager
 from servicemanager import ServiceManager

=== renamed file 'openlp/core/ui/displaytagdialog.py' => 'openlp/core/ui/formattingtagdialog.py'
--- openlp/core/ui/displaytagdialog.py	2011-07-07 18:03:12 +0000
+++ openlp/core/ui/formattingtagdialog.py	2011-07-30 08:21:12 +0000
@@ -30,15 +30,15 @@
 from openlp.core.lib import translate
 from openlp.core.lib.ui import UiStrings
 
-class Ui_DisplayTagDialog(object):
+class Ui_FormattingTagDialog(object):
 
-    def setupUi(self, displayTagDialog):
-        displayTagDialog.setObjectName(u'displayTagDialog')
-        displayTagDialog.resize(725, 548)
-        self.listdataGridLayout = QtGui.QGridLayout(displayTagDialog)
+    def setupUi(self, formattingTagDialog):
+        formattingTagDialog.setObjectName(u'formattingTagDialog')
+        formattingTagDialog.resize(725, 548)
+        self.listdataGridLayout = QtGui.QGridLayout(formattingTagDialog)
         self.listdataGridLayout.setMargin(8)
         self.listdataGridLayout.setObjectName(u'listdataGridLayout')
-        self.tagTableWidget = QtGui.QTableWidget(displayTagDialog)
+        self.tagTableWidget = QtGui.QTableWidget(formattingTagDialog)
         self.tagTableWidget.setHorizontalScrollBarPolicy(
             QtCore.Qt.ScrollBarAlwaysOff)
         self.tagTableWidget.setEditTriggers(
@@ -67,11 +67,11 @@
         spacerItem = QtGui.QSpacerItem(40, 20,
             QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
         self.horizontalLayout.addItem(spacerItem)
-        self.deletePushButton = QtGui.QPushButton(displayTagDialog)
+        self.deletePushButton = QtGui.QPushButton(formattingTagDialog)
         self.deletePushButton.setObjectName(u'deletePushButton')
         self.horizontalLayout.addWidget(self.deletePushButton)
         self.listdataGridLayout.addLayout(self.horizontalLayout, 1, 0, 1, 1)
-        self.editGroupBox = QtGui.QGroupBox(displayTagDialog)
+        self.editGroupBox = QtGui.QGroupBox(formattingTagDialog)
         self.editGroupBox.setObjectName(u'editGroupBox')
         self.dataGridLayout = QtGui.QGridLayout(self.editGroupBox)
         self.dataGridLayout.setObjectName(u'dataGridLayout')
@@ -112,38 +112,38 @@
         self.savePushButton.setObjectName(u'savePushButton')
         self.dataGridLayout.addWidget(self.savePushButton, 4, 2, 1, 1)
         self.listdataGridLayout.addWidget(self.editGroupBox, 2, 0, 1, 1)
-        self.buttonBox = QtGui.QDialogButtonBox(displayTagDialog)
-        self.buttonBox.setObjectName('displayTagDialogButtonBox')
+        self.buttonBox = QtGui.QDialogButtonBox(formattingTagDialog)
+        self.buttonBox.setObjectName('formattingTagDialogButtonBox')
         self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Close)
         self.listdataGridLayout.addWidget(self.buttonBox, 3, 0, 1, 1)
 
-        self.retranslateUi(displayTagDialog)
-        QtCore.QMetaObject.connectSlotsByName(displayTagDialog)
+        self.retranslateUi(formattingTagDialog)
+        QtCore.QMetaObject.connectSlotsByName(formattingTagDialog)
 
-    def retranslateUi(self, displayTagDialog):
-        displayTagDialog.setWindowTitle(translate('OpenLP.displayTagDialog',
-            'Configure Display Tags'))
+    def retranslateUi(self, formattingTagDialog):
+        formattingTagDialog.setWindowTitle(translate(
+            'OpenLP.FormattingTagDialog', 'Configure Formatting Tags'))
         self.editGroupBox.setTitle(
-            translate('OpenLP.DisplayTagDialog', 'Edit Selection'))
+            translate('OpenLP.FormattingTagDialog', 'Edit Selection'))
         self.savePushButton.setText(
-            translate('OpenLP.DisplayTagDialog', 'Save'))
+            translate('OpenLP.FormattingTagDialog', 'Save'))
         self.descriptionLabel.setText(
-            translate('OpenLP.DisplayTagDialog', 'Description'))
-        self.tagLabel.setText(translate('OpenLP.DisplayTagDialog', 'Tag'))
+            translate('OpenLP.FormattingTagDialog', 'Description'))
+        self.tagLabel.setText(translate('OpenLP.FormattingTagDialog', 'Tag'))
         self.startTagLabel.setText(
-            translate('OpenLP.DisplayTagDialog', 'Start tag'))
+            translate('OpenLP.FormattingTagDialog', 'Start tag'))
         self.endTagLabel.setText(
-            translate('OpenLP.DisplayTagDialog', 'End tag'))
+            translate('OpenLP.FormattingTagDialog', 'End tag'))
         self.deletePushButton.setText(UiStrings().Delete)
         self.newPushButton.setText(UiStrings().New)
         self.tagTableWidget.horizontalHeaderItem(0).setText(
-            translate('OpenLP.DisplayTagDialog', 'Description'))
+            translate('OpenLP.FormattingTagDialog', 'Description'))
         self.tagTableWidget.horizontalHeaderItem(1).setText(
-            translate('OpenLP.DisplayTagDialog', 'Tag Id'))
+            translate('OpenLP.FormattingTagDialog', 'Tag Id'))
         self.tagTableWidget.horizontalHeaderItem(2).setText(
-            translate('OpenLP.DisplayTagDialog', 'Start HTML'))
+            translate('OpenLP.FormattingTagDialog', 'Start HTML'))
         self.tagTableWidget.horizontalHeaderItem(3).setText(
-            translate('OpenLP.DisplayTagDialog', 'End HTML'))
+            translate('OpenLP.FormattingTagDialog', 'End HTML'))
         self.tagTableWidget.setColumnWidth(0, 120)
         self.tagTableWidget.setColumnWidth(1, 80)
         self.tagTableWidget.setColumnWidth(2, 330)

=== renamed file 'openlp/core/ui/displaytagform.py' => 'openlp/core/ui/formattingtagform.py'
--- openlp/core/ui/mainwindow.py	2011-07-12 19:06:37 +0000
+++ openlp/core/ui/mainwindow.py	2011-07-30 08:21:12 +0000
@@ -38,7 +38,7 @@
     icon_action, shortcut_action
 from openlp.core.ui import AboutForm, SettingsForm, ServiceManager, \
     ThemeManager, SlideController, PluginForm, MediaDockManager, \
-    ShortcutListForm, DisplayTagForm
+    ShortcutListForm, FormattingTagForm
 from openlp.core.utils import AppLocation, add_actions, LanguageManager, \
     get_application_version, delete_file
 from openlp.core.utils.actions import ActionList, CategoryOrder
@@ -269,7 +269,8 @@
             u'settingsShortcutsItem',
             u':/system/system_configure_shortcuts.png',
             category=UiStrings().Settings)
-        self.displayTagItem = icon_action(mainWindow,
+        # Formatting Tags were also known as display tags.
+        self.formattingTagItem = icon_action(mainWindow,
             u'displayTagItem', u':/system/tag_editor.png',
             category=UiStrings().Settings)
         self.settingsConfigureItem = icon_action(mainWindow,
@@ -315,11 +316,11 @@
             add_actions(self.settingsMenu, (self.settingsPluginListItem,
                 self.settingsLanguageMenu.menuAction(), None,
                 self.settingsConfigureItem, self.settingsShortcutsItem,
-                self.displayTagItem))
+                self.formattingTagItem))
         else:
             add_actions(self.settingsMenu, (self.settingsPluginListItem,
                 self.settingsLanguageMenu.menuAction(), None,
-                self.displayTagItem, self.settingsShortcutsItem,
+                self.formattingTagItem, self.settingsShortcutsItem,
                 self.settingsConfigureItem))
         add_actions(self.toolsMenu, (self.toolsAddToolItem, None))
         add_actions(self.toolsMenu, (self.toolsOpenDataFolder, None))
@@ -403,8 +404,8 @@
             translate('OpenLP.MainWindow', '&Language'))
         self.settingsShortcutsItem.setText(
             translate('OpenLP.MainWindow', 'Configure &Shortcuts...'))
-        self.displayTagItem.setText(
-            translate('OpenLP.MainWindow', '&Configure Display Tags'))
+        self.formattingTagItem.setText(
+            translate('OpenLP.MainWindow', '&Configure Formatting Tags...'))
         self.settingsConfigureItem.setText(
             translate('OpenLP.MainWindow', '&Configure OpenLP...'))
         self.viewMediaManagerItem.setText(
@@ -511,7 +512,7 @@
         self.serviceNotSaved = False
         self.aboutForm = AboutForm(self)
         self.settingsForm = SettingsForm(self, self)
-        self.displayTagForm = DisplayTagForm(self)
+        self.formattingTagForm = FormattingTagForm(self)
         self.shortcutForm = ShortcutListForm(self)
         self.recentFiles = QtCore.QStringList()
         # Set up the path with plugins
@@ -548,8 +549,8 @@
             QtCore.SIGNAL(u'triggered()'), self.onToolsOpenDataFolderClicked)
         QtCore.QObject.connect(self.updateThemeImages,
             QtCore.SIGNAL(u'triggered()'), self.onUpdateThemeImages)
-        QtCore.QObject.connect(self.displayTagItem,
-            QtCore.SIGNAL(u'triggered()'), self.onDisplayTagItemClicked)
+        QtCore.QObject.connect(self.formattingTagItem,
+            QtCore.SIGNAL(u'triggered()'), self.onFormattingTagItemClicked)
         QtCore.QObject.connect(self.settingsConfigureItem,
             QtCore.SIGNAL(u'triggered()'), self.onSettingsConfigureItemClicked)
         QtCore.QObject.connect(self.settingsShortcutsItem,
@@ -788,11 +789,11 @@
         """
         self.themeManagerContents.updatePreviewImages()
 
-    def onDisplayTagItemClicked(self):
+    def onFormattingTagItemClicked(self):
         """
         Show the Settings dialog
         """
-        self.displayTagForm.exec_()
+        self.formattingTagForm.exec_()
 
     def onSettingsConfigureItemClicked(self):
         """

=== modified file 'openlp/core/ui/shortcutlistdialog.py'
--- openlp/core/ui/shortcutlistdialog.py	2011-06-12 16:02:52 +0000
+++ openlp/core/ui/shortcutlistdialog.py	2011-07-30 08:21:12 +0000
@@ -123,7 +123,7 @@
 
     def retranslateUi(self, shortcutListDialog):
         shortcutListDialog.setWindowTitle(
-            translate('OpenLP.ShortcutListDialog', 'Customize Shortcuts'))
+            translate('OpenLP.ShortcutListDialog', 'Configure Shortcuts'))
         self.descriptionLabel.setText(translate('OpenLP.ShortcutListDialog',
             'Select an action and click one of the buttons below to start '
             'capturing a new primary or alternate shortcut, respectively.'))


Follow ups
--- openlp/core/ui/displaytagform.py	2011-06-26 14:37:38 +0000
+++ openlp/core/ui/formattingtagform.py	2011-07-30 08:21:12 +0000
@@ -25,22 +25,22 @@
 # Temple Place, Suite 330, Boston, MA 02111-1307 USA                          #
 ###############################################################################
 """
-The :mod:`DisplayTagTab` provides an Tag Edit facility.  The Base set are
-protected and included each time loaded.  Custom tags can be defined and saved.
-The Custom Tag arrays are saved in a pickle so QSettings works on them.  Base
+The :mod:`formattingtagform` provides an Tag Edit facility. The Base set are
+protected and included each time loaded. Custom tags can be defined and saved.
+The Custom Tag arrays are saved in a pickle so QSettings works on them. Base
 Tags cannot be changed.
 """
 import cPickle
 
 from PyQt4 import QtCore, QtGui
 
-from openlp.core.lib import translate, DisplayTags
+from openlp.core.lib import translate, FormattingTags
 from openlp.core.lib.ui import critical_error_message_box
-from openlp.core.ui.displaytagdialog import Ui_DisplayTagDialog
+from openlp.core.ui.formattingtagdialog import Ui_FormattingTagDialog
 
-class DisplayTagForm(QtGui.QDialog, Ui_DisplayTagDialog):
+class FormattingTagForm(QtGui.QDialog, Ui_FormattingTagDialog):
     """
     The :class:`DisplayTagTab` manages the settings tab .
     """
     def __init__(self, parent):
         """
@@ -48,7 +48,7 @@
         """
         QtGui.QDialog.__init__(self, parent)
         self.setupUi(self)
-        self._loadDisplayTags()
+        self._loadFormattingTags()
         QtCore.QObject.connect(self.tagTableWidget,
             QtCore.SIGNAL(u'clicked(QModelIndex)'), self.onRowSelected)
         QtCore.QObject.connect(self.newPushButton,
@@ -65,19 +65,20 @@
         Load Display and set field state.
         """
         # Create initial copy from master
-        self._loadDisplayTags()
+        self._loadFormattingTags()
         self._resetTable()
         self.selected = -1
         return QtGui.QDialog.exec_(self)
 
-    def _loadDisplayTags(self):
+    def _loadFormattingTags(self):
         """
         Load the Tags from store so can be used in the system or used to
         update the display. If Cancel was selected this is needed to reset the
         dsiplay to the correct version.
         """
         # Initial Load of the Tags
-        DisplayTags.reset_html_tags()
+        FormattingTags.reset_html_tags()
+        # Formatting Tags were also known as display tags.
         user_expands = QtCore.QSettings().value(u'displayTags/html_tags',
             QtCore.QVariant(u'')).toString()
         # cPickle only accepts str not unicode strings
@@ -85,14 +86,14 @@
         if user_expands_string:
             user_tags = cPickle.loads(user_expands_string)
             # If we have some user ones added them as well
-            DisplayTags.add_html_tags(user_tags)
+            FormattingTags.add_html_tags(user_tags)
 
     def onRowSelected(self):
         """
         Table Row selected so display items and set field state.
         """
         row = self.tagTableWidget.currentRow()
-        html = DisplayTags.get_html_tags()[row]
+        html = FormattingTags.get_html_tags()[row]
         self.selected = row
         self.descriptionLineEdit.setText(html[u'desc'])
         self.tagLineEdit.setText(self._strip(html[u'start tag']))
@@ -117,23 +118,23 @@
         """
         Add a new tag to list only if it is not a duplicate.
         """
-        for html in DisplayTags.get_html_tags():
+        for html in FormattingTags.get_html_tags():
             if self._strip(html[u'start tag']) == u'n':
                 critical_error_message_box(
-                    translate('OpenLP.DisplayTagTab', 'Update Error'),
-                    translate('OpenLP.DisplayTagTab',
+                    translate('OpenLP.FormattingTagForm', 'Update Error'),
+                    translate('OpenLP.FormattingTagForm',
                     'Tag "n" already defined.'))
                 return
         # Add new tag to list
         tag = {
-            u'desc': translate('OpenLP.DisplayTagTab', 'New Tag'),
+            u'desc': translate('OpenLP.FormattingTagForm', 'New Tag'),
             u'start tag': u'{n}',
-            u'start html': translate('OpenLP.DisplayTagTab', '<HTML here>'),
+            u'start html': translate('OpenLP.FormattingTagForm', '<HTML here>'),
             u'end tag': u'{/n}',
-            u'end html': translate('OpenLP.DisplayTagTab', '</and here>'),
+            u'end html': translate('OpenLP.FormattingTagForm', '</and here>'),
             u'protected': False
         }
-        DisplayTags.add_html_tags([tag])
+        FormattingTags.add_html_tags([tag])
         self._resetTable()
         # Highlight new row
         self.tagTableWidget.selectRow(self.tagTableWidget.rowCount() - 1)
@@ -145,7 +146,7 @@
         Delete selected custom tag.
         """
         if self.selected != -1:
-            DisplayTags.remove_html_tag(self.selected)
+            FormattingTags.remove_html_tag(self.selected)
             self.selected = -1
         self._resetTable()
         self._saveTable()
@@ -154,7 +155,7 @@
         """
         Update Custom Tag details if not duplicate and save the data.
         """
-        html_expands = DisplayTags.get_html_tags()
+        html_expands = FormattingTags.get_html_tags()
         if self.selected != -1:
             html = html_expands[self.selected]
             tag = unicode(self.tagLineEdit.text())
@@ -162,8 +163,8 @@
                 if self._strip(html1[u'start tag']) == tag and \
                     linenumber != self.selected:
                     critical_error_message_box(
-                        translate('OpenLP.DisplayTagTab', 'Update Error'),
-                        unicode(translate('OpenLP.DisplayTagTab',
+                        translate('OpenLP.FormattingTagForm', 'Update Error'),
+                        unicode(translate('OpenLP.FormattingTagForm',
                         'Tag %s already defined.')) % tag)
                     return
             html[u'desc'] = unicode(self.descriptionLineEdit.text())
@@ -177,18 +178,15 @@
 
     def _saveTable(self):
         """
         Saves all display tags except protected ones.
         """
         tags = []
-        for tag in DisplayTags.get_html_tags():
+        for tag in FormattingTags.get_html_tags():
             if not tag[u'protected']:
                 tags.append(tag)
-        if tags:
-            QtCore.QSettings().setValue(u'displayTags/html_tags',
-                QtCore.QVariant(cPickle.dumps(tags)))
-        else:
-            QtCore.QSettings().setValue(u'displayTags/html_tags',
-                QtCore.QVariant(u''))
+        # Formatting Tags were also known as display tags.
+        QtCore.QSettings().setValue(u'displayTags/html_tags',
+            QtCore.QVariant(cPickle.dumps(tags) if tags else u''))
 
     def _resetTable(self):
         """
@@ -199,7 +197,7 @@
         self.newPushButton.setEnabled(True)
         self.savePushButton.setEnabled(False)
         self.deletePushButton.setEnabled(False)
-        for linenumber, html in enumerate(DisplayTags.get_html_tags()):
+        for linenumber, html in enumerate(FormattingTags.get_html_tags()):
             self.tagTableWidget.setRowCount(
                 self.tagTableWidget.rowCount() + 1)
             self.tagTableWidget.setItem(linenumber, 0,
@@ -25,22 +25,22 @@
     """
-    The :class:`DisplayTagTab` manages the settings tab .
+    The :class:`FormattingTagForm` manages the settings tab .
     """
     def __init__(self, parent):
@@ -177,18 +178,15 @@
     def _saveTable(self):
         """
-        Saves all display tags except protected ones.
+        Saves all formatting tags except protected ones.
         """
         tags = []

=== modified file 'openlp/core/ui/mainwindow.py'